@@ -41,6 +41,7 @@ def PUT(func):
         else:
             return func(*args,**kw)
     return wrapper
+
 def DELETE(func):
     """ DELETE function decorator """
     def wrapper(*args,**kw):
@@ -57,13 +58,34 @@ def DELETE(func):
 
 # Pull config from config.ini
 class StatusCastAPIDriver:
-    def __init__(self,password="",username="",base_url="",verify_ssl=False):
-        # Parse the arguments
-        # Optional
-        self.args = self.parse_args()
+    def __init__(self):
+        """ Constructor for StatusCastAPIDriver. You need to call .initialize_session() on this object after
+        creation, passing username (str),password (str),base_url (str),and verify_ssl (boolean) to that method
+        to create an authenticated API session. """
+        self.username = ""
+        self.password = ""
+        self.base_url = ""
+        self.verify_ssl = False
+        self.session_initialized = False
 
+    def __str__(self):
+        if self.session_initialized:
+            msg = "StatusCastAPIDriver object with an initialized session, with " \
+                "username={},base_url={},verify_ssl={},password={}".format(
+                    self.username,self.base_url,self.verify_ssl,self.password
+                )
+        else:
+            msg = "StatusCastAPIDriver object without an initialized session"
+        return msg
+
+    def initialize_session(self, password="",username="",base_url="",verify_ssl=False):
+        """
+        Initialize an authorized session using username/password/base_url/verify_ssl args
+        by getting a token and updating session headers with that token
+        """
         if username == "":
             print("You must provide a valid value for username, ({} is not a valid value)".format(username))
+            print("Alternatively, provide ")
             sys.exit(1)
         elif password == "":
             print("You must provide a valid value for password, ({} is not a valid value)".format(password))
@@ -74,38 +96,10 @@ class StatusCastAPIDriver:
         elif verify_ssl == "":
             print("You must provide a valid value for verify_ssl, ({} is not a valid value)".format(verify_ssl))
             sys.exit(1)
-        self.password = password
-        self.username = username
-        self.base_url = base_url
-        self.verify_ssl = verify_ssl
+        else:
+            # All values provided
+            self.username,self.password,self.base_url,self.verify_ssl=username,password,base_url,verify_ssl
 
-
-
-    def setConfig(self,filename=None):
-        """ Set a config file path with a key [statuscast] and values
-         username, password, base_url, and verify_ssl """
-        if filename:
-            try:
-                config = configparser.ConfigParser()
-                config.read(filename)
-                return config
-            except Exception as e:
-                print(e)
-                print("You should create a config file containing:" + \
-                    "\n\tusername = <username to get auth token>\n\t" + \
-                    "\n\tpassword = <password to get auth token>\n\t" + \
-                    "\n\tbase_url = <API base URL>\n\t" + \
-                    "\n\tverify_ssl = <True/False>\n\t")
-                print("And then pass the path of that config file with --config <path>")
-                sys.exit(1)
-
-
-
-    def initialize_session(self):
-        """
-        Initialize an authorized session by getting a token and updating session headers with
-        that token
-        """
         data = {
             'grant_type': "password",
             'username': self.username,
@@ -122,6 +116,7 @@ class StatusCastAPIDriver:
         # implicitly stored with session
         try:
             access_token = r.json()['access_token']
+            self.session_initialized = True
         except:
             print("Access token was not in response: response was {}".format(r.content))
             access_token = ""
@@ -129,38 +124,9 @@ class StatusCastAPIDriver:
         # Now this token is passed for all additional API calls inherently
         auth_session.headers.update({'Authorization': 'Bearer {}'.format(access_token)})
         self.auth_session = auth_session
-        return auth_session
 
 
-    def parse_args(self):
-        """ Parse arguments. Note that you shouldn't use any self.<> variables dependent on config file, because
-        the setConfig() method depends on the completion of this method (--config is passed as an argument.)"""
 
-        parser = argparse.ArgumentParser(description="Process arguments for status_cofc_edu job execution")
-        # Parse the arguments, turn them into variables
-        # Endpoint argument, one value -> nargs=?
-
-        # API Endpoint and HTTP Method are required.
-        parser.add_argument('--endpoint', metavar='e', type=str, nargs=1,
-                        help='an endpoint to hit, e.g. subscribers')
-        parser.add_argument('--method', metavar='m', type=str, nargs=1,
-                        help='HTTP Method to use (GET, POST, PUT, or DELETE)')
-
-        # Post request requires payload.
-        parser.add_argument('--payload', metavar='p', type=str, nargs='*',
-                            help='data payload formatted as \'{"key1":"value1","key2":"value2"}\'')
-
-        parser.add_argument('--queryargs', metavar='q', type=str, nargs='*',
-                            help='GET query arguments formatted as \'{"key1":"value1","key2":"value2"}\'')
-
-        parser.add_argument('--config', metavar='o',type=str,nargs=1,
-                            help='path to configuration file storing: ' + \
-                                "\n\tusername = <username to get auth token>\n\t" + \
-                                "\n\tpassword = <password to get auth token>\n\t" + \
-                                "\n\tbase_url = <API base URL>\n\t" + \
-                                "\n\tverify_ssl = <True/False>\n\t")
-
-        return parser.parse_args()
 
 
     # Method to parse dictionary/JSON object from '{"key1":"val1","key2":"val2"}' data format
@@ -235,11 +201,11 @@ class StatusCastAPIDriver:
         # Ensure presence of required data fields
         required_data = ["emailaddress"]
         if self.validate_data_keys(data,required_data):
-            r = self.auth_session.post(endpoint,data=data,verify=self.verify_ssl)
+            r = self.auth_session.post("{}{}".format(self.base_url,endpoint),data=data,verify=self.verify_ssl)
             return r, r.content
         else:
             print("POST request to {} requires data: {}".format(endpoint,','.join(required_data)))
-            sys.exit(1)
+            return None,None
 
     @POST
     def account_resetpassword(self,endpoint,method,data):
@@ -249,26 +215,27 @@ class StatusCastAPIDriver:
         # Ensure presence of required data fields
         required_data = ["userid","token","password","confirmPassword"]
         if self.validate_data_keys(data,required_data):
-            r = self.auth_session.post(endpoint,data=data,verify=self.verify_ssl)
+            r = self.auth_session.post("{}{}".format(self.base_url,endpoint),data=data,verify=self.verify_ssl)
             return r, r.content
         else:
             print("POST request to {} requires data: {}".format(endpoint,','.join(required_data)))
-            sys.exit(1)
+            return None,None
 
 
     def account_subscriptions_router(self,endpoint,method,data):
         """ Sub router for account_subscriptions; can be GET or POST """
         if m(method) == "get":
-            return self.account_subscriptions_get(endpoint,method,data)
+            return self.account_subscriptions_get("{}{}".format(self.base_url,endpoint),method,data)
         elif m(method) == "post":
-            return self.account_subscriptions_post(endpoint,method,data)
+            return self.account_subscriptions_post("{}{}".format(self.base_url,endpoint),method,data)
         else:
             print("{} is an invalid method for {}".format(method,endpoint))
+            return None,None
     @GET
     def account_subscriptions_get(self, endpoint,method,data):
         """ Handler for GET account subcriptions request """
         print("Getting {}".format(endpoint))
-        r = self.auth_session.get(endpoint,verify=self.verify_ssl)
+        r = self.auth_session.get("{}{}".format(self.base_url,endpoint),verify=self.verify_ssl)
         return r, json.loads(r.content)
 
     @POST
@@ -284,30 +251,31 @@ class StatusCastAPIDriver:
             ]
 
         if self.validate_data_keys(data,required_data):
-            r = self.auth_session.post(endpoint,data=data,verify=self.verify_ssl)
+            r = self.auth_session.post("{}{}".format(self.base_url,endpoint),data=data,verify=self.verify_ssl)
             return r, r.content
         else:
             print("POST request to {} requires data: {}".format(endpoint,','.join(required_data)))
-            sys.exit(1)
+            return None,None
 
 
     def components_router(self,endpoint,method,data):
         """ Subrouter for the the /components endpoint """
         if m(method) == "get":
-            return self.components_get(endpoint,method,data)
+            return self.components_get("{}{}".format(self.base_url,endpoint),method,data)
         elif m(method) == "post":
             return self.components_create(endpoint,method,data)
         elif m(method) == "delete":
-            return self.components_delete(endpoint,method,data)
+            return self.components_delete("{}{}".format(self.base_url,endpoint),method,data)
         elif m(method) == "put":
             return self.components_update(endpoint,method,data)
         else:
             print("{} is an invalid method for {}".format(method,endpoint))
+            return None,None
 
     @GET
     def components_get(self,endpoint,method,data):
         """ Handler for components GET request; endpoint can be /components/<id> or /components """
-        r = self.auth_session.get(endpoint,data=data,verify=self.verify_ssl)
+        r = self.auth_session.get("{}{}".format(self.base_url,endpoint),data=data,verify=self.verify_ssl)
         return r, json.loads(r.content)
 
 
@@ -319,11 +287,11 @@ class StatusCastAPIDriver:
         # Ensure presence of required data fields
         required_data = ["name","description","priority","parentId","isHidden"]
         if self.validate_data_keys(data,required_data):
-            r = self.auth_session.post(endpoint,data=data,verify=self.verify_ssl)
+            r = self.auth_session.post("{}{}".format(self.base_url,endpoint),data=data,verify=self.verify_ssl)
             return r, r.content
         else:
             print("POST request to {} requires data: {}".format(endpoint,','.join(required_data)))
-            sys.exit(1)
+            return None,None
 
     @DELETE
     def components_delete(self,endpoint,method,data):
@@ -331,38 +299,38 @@ class StatusCastAPIDriver:
         Handler for components DELETE request; endpoint must be /components/<id>
         """
         if "?id=" in endpoint:
-            r = self.auth_session.delete(endpoint,data=data,verify=self.verify_ssl)
+            r = self.auth_session.delete("{}{}".format(self.base_url,endpoint),data=data,verify=self.verify_ssl)
             return r, r.content
         else:
             print("DELETE request to {} requires data: ?id=<id to delete> in URL".format(endpoint))
-            sys.exit(1)
+            return None,None
 
     @PUT
     def components_update(self,endpoint,method,data):
         """ Handler for components update request; endpoint must be /components?id=<id to update> """
         required_data = ["name","description","priority","parentId","isHidden"]
         if self.validate_data_keys(data,required_data) and "?id=" in endpoint:
-            r = self.auth_session.put(endpoint,data=data,verify=self.verify_ssl)
+            r = self.auth_session.put("{}{}".format(self.base_url,endpoint),data=data,verify=self.verify_ssl)
             return r, r.content
         else:
             print("DELETE request to {} requires data: {}".format(endpoint,','.join(required_data)))
-            sys.exit(1)
+            return None,None
 
 
 
     def incidents_router(self,endpoint,method,data):
         """ Subrouter for the the /incidents endpoint """
         if m(method) == "get":
-            return self.incidents_get(endpoint,method,data)
+            return self.incidents_get("{}{}".format(self.base_url,endpoint),method,data)
         elif m(method) == "post":
             return self.incidents_create(endpoint,method,data)
         elif m(method) == "delete":
-            return self.incidents_delete(endpoint,method,data)
+            return self.incidents_delete("{}{}".format(self.base_url,endpoint),method,data)
         elif m(method) == "put":
             return self.incidents_update(endpoint,method,data)
         else:
             print("{} is an invalid method for {}".format(method,endpoint))
-
+            return None,None
 
     @POST
     def incidents_create(self,endpoint,method,data):
@@ -386,22 +354,22 @@ class StatusCastAPIDriver:
                     "affectedComponents"
         ]
         if self.validate_data_keys(data,required_data):
-            r = self.auth_session.post(endpoint,data=data,verify=self.verify_ssl)
+            r = self.auth_session.post("{}{}".format(self.base_url,endpoint),data=data,verify=self.verify_ssl)
             return r, r.content
         else:
             print("POST request to {} requires data: {}".format(endpoint,','.join(required_data)))
-            sys.exit(1)
+            return None,None
     @DELETE
     def incidents_delete(self,endpoint,method,data):
         """
         Handler for incidents DELETE request; endpoint must be /incidents/<id>
         """
         if "?id=" in endpoint:
-            r = self.auth_session.delete(endpoint,data=data,verify=self.verify_ssl)
+            r = self.auth_session.delete("{}{}".format(self.base_url,endpoint),data=data,verify=self.verify_ssl)
             return r, r.content
         else:
             print("DELETE request to {} requires data: ?id=<id to delete> in URL".format(endpoint))
-            sys.exit(1)
+            return None,None
 
     @PUT
     def incidents_update(self,endpoint,method,data):
@@ -422,11 +390,11 @@ class StatusCastAPIDriver:
                     "affectedComponents"
         ]
         if self.validate_data_keys(data,required_data) and "?id=" in endpoint:
-            r = self.auth_session.put(endpoint,data=data,verify=self.verify_ssl)
+            r = self.auth_session.put("{}{}".format(self.base_url,endpoint),data=data,verify=self.verify_ssl)
             return r, r.content
         else:
             print("PUT request to {} requires ?id=<id to update> at end of URL and data payload {}".format(endpoint,','.join(required_data)))
-            sys.exit(1)
+            return None,None
     @GET
     def incidents_get(self,endpoint,method,data):
         """ Handler for incidents GET request; endpoint can be:
@@ -436,17 +404,17 @@ class StatusCastAPIDriver:
           """
         # Doesn't require parameters, so just execute request
         if "incidenttypes" in endpoint:
-            r = self.auth_session.get(endpoint,verify=self.verify_ssl)
+            r = self.auth_session.get("{}{}".format(self.base_url,endpoint),verify=self.verify_ssl)
             return r, json.loads(r.content)
         elif "?id=" in endpoint:
-            r = self.auth_session.get(endpoint,verify=self.verify_ssl)
+            r = self.auth_session.get("{}{}".format(self.base_url,endpoint),verify=self.verify_ssl)
             return r, json.loads(r.content)
         elif "?start=" in endpoint and "end=" in endpoint:
-            r = self.auth_session.get(endpoint,verify=self.verify_ssl)
+            r = self.auth_session.get("{}{}".format(self.base_url,endpoint),verify=self.verify_ssl)
             return r, json.loads(r.content)
         else:
             print("Cannot perform GET request on endpoint {}".format(endpoint))
-            sys.exit(1)
+            return None,None
 
 
     @POST
@@ -454,11 +422,11 @@ class StatusCastAPIDriver:
         """ Handler for the metrics/custom POST request """
         required_data = ["id","value","timestamp"]
         if self.validate_data_keys(data,required_data):
-            r = self.auth_session.post(endpoint,data=data,verify=self.verify_ssl)
+            r = self.auth_session.post("{}{}".format(self.base_url,endpoint),data=data,verify=self.verify_ssl)
             return r, r.content
         else:
             print("POST request to {} requires data: {}".format(endpoint,','.join(required_data)))
-            sys.exit(1)
+            return None,None
     @GET
     def search_incidents_router(self,endpoint,method,data):
         """ Router for search incidents GET request; must include at least one of any of the following optional params:
@@ -467,7 +435,7 @@ class StatusCastAPIDriver:
         maxDate			optional		Date		reduce the query to dates less than or equal to this parameter
         includeChildren	optional		Boolean		when given a componentId, include that component's children as part of the result.
         """
-        r = self.auth_session.get(endpoint,verify=self.verify_ssl)
+        r = self.auth_session.get("{}{}".format(self.base_url,endpoint),verify=self.verify_ssl)
         return r, json.loads(r.content)
 
 
@@ -490,21 +458,22 @@ class StatusCastAPIDriver:
             return self.statuspage_settings(endpoint,method,data)
         elif endpoint.endswith('statuspage') or endpoint.endswith('statuspage/'):
             # Valid get request, must be GET though. No data/payload.
-            r = self.auth_session.post(endpoint,verify=self.verify_ssl)
+            r = self.auth_session.post("{}{}".format(self.base_url,endpoint),verify=self.verify_ssl)
             return r, json.loads(r.content)
         else:
             print("Invalid endpoint given: {}".format(endpoint))
+            return None,None
 
     @POST
     def statuspage_addhit(self,endpoint,method,data):
         """ Handler for POST /statuspage/addhit request """
         # Rare: post request that does not require data; hits an endpoint, increments a counter on their end.
-        r = self.auth_session.post(endpoint,data=data,verify=self.verify_ssl)
+        r = self.auth_session.post("{}{}".format(self.base_url,endpoint),data=data,verify=self.verify_ssl)
         return r, r.content
     @GET
     def statuspage_css(self,endpoint,method,data):
         """ Handler for GET /statuspage/css request """
-        r = self.auth_session.get(endpoint,data=data,verify=self.verify_ssl)
+        r = self.auth_session.get("{}{}".format(self.base_url,endpoint),data=data,verify=self.verify_ssl)
         return r, r.content # Not json; is a CSS string e.g. "body { background: white }"
 
     @GET
@@ -513,33 +482,33 @@ class StatusCastAPIDriver:
         Requires start and end date
         """
         if "?start=" in endpoint and "end=" in endpoint:
-            r = self.auth_session.get(endpoint,data=data,verify=self.verify_ssl)
+            r = self.auth_session.get("{}{}".format(self.base_url,endpoint),data=data,verify=self.verify_ssl)
             return r, json.loads(r.content)
         else:
             print("GET request to {} requires data: ?start=<start date>&end=<end date> in URL".format(endpoint))
-            sys.exit(1)
+            return None,None
     @GET
     def statuspage_dashboardposts(self, endpoint,method,data):
         """ Handler for GET /statuspage/dashboardposts
         Requires date to receive posts for
          """
         if "?date=" in endpoint:
-            r = self.auth_session.get(endpoint,data=data,verify=self.verify_ssl)
+            r = self.auth_session.get("{}{}".format(self.base_url,endpoint),data=data,verify=self.verify_ssl)
             return r, json.loads(r.content)
         else:
             print("GET request to {} requires data: ?date=<date to receive posts> in URL".format(endpoint))
-            sys.exit(1)
+            return None,None
     @GET
-    def statuspage_dashboardposts(self, endpoint,method,data):
+    def statuspage_dashboardgrid(self, endpoint,method,data):
         """ Handler for GET /statuspage/dashboardgrid
         Requires offset (number of days offset from current date)
         """
         if "?offset=" in endpoint:
-            r = self.auth_session.get(endpoint,data=data,verify=self.verify_ssl)
+            r = self.auth_session.get("{}{}".format(self.base_url,endpoint),data=data,verify=self.verify_ssl)
             return r, json.loads(r.content)
         else:
             print("GET request to {} requires data: ?offset=<number of days offset from current date> in URL".format(endpoint))
-            sys.exit(1)
+            return None,None
 
     @GET
     def statuspage_metrics(self, endpoint,method,data):
@@ -550,15 +519,15 @@ class StatusCastAPIDriver:
         metricId: id of metric to receive data for
         """
         if "type=" in endpoint and "period=" in endpoint and "metricId=" in endpoint:
-            r = self.auth_session.get(endpoint,data=data,verify=self.verify_ssl)
+            r = self.auth_session.get("{}{}".format(self.base_url,endpoint),data=data,verify=self.verify_ssl)
             return r, r.content
         else:
             print("GET request to {} requires data: ?type=<pingdom, newrelic or custom>&period=<Day,Week,Month>&metricId=<id of metric to get data for> in URL".format(endpoint))
-            sys.exit(1)
+            return None,None
     @GET
     def statuspage_settings(self, endpoint,method,data):
         """ Handler for GET /statuspage/settings """
-        r = self.auth_session.get(endpoint,data=data,verify=self.verify_ssl)
+        r = self.auth_session.get("{}{}".format(self.base_url,endpoint),data=data,verify=self.verify_ssl)
         return r, json.loads(r.content)
 
 
@@ -569,13 +538,14 @@ class StatusCastAPIDriver:
         Options from here are GET, POST, DELETE
         """
         if m(method) == "delete":
-            return self.subscribers_delete(endpoint,method,data)
+            return self.subscribers_delete("{}{}".format(self.base_url,endpoint),method,data)
         elif m(method) == "post":
             return self.subscribers_invite(endpoint,method,data)
         elif m(method) == "get":
             return self.subscribers_list(endpoint,method,data)
         else:
             print("{} is an invalid method for {}".format(method,endpoint))
+            return None,None
 
     @DELETE
     def subscribers_delete(self, endpoint,method,data):
@@ -583,11 +553,11 @@ class StatusCastAPIDriver:
         Handler for subscriber DELETE request; endpoint must be /components/<id to delete>
         """
         if "?id=" in endpoint:
-            r = self.auth_session.delete(endpoint,data=data,verify=self.verify_ssl)
+            r = self.auth_session.delete("{}{}".format(self.base_url,endpoint),data=data,verify=self.verify_ssl)
             return r, r.content
         else:
             print("DELETE request to {} requires data: ?id=<id to delete> in URL".format(endpoint))
-            sys.exit(1)
+            return None,None
 
 
     @POST
@@ -601,11 +571,11 @@ class StatusCastAPIDriver:
          """
         required_data = ["emailAddress","createAccount","sendPassword","components"]
         if self.validate_data_keys(data,required_data):
-            r = self.auth_session.post(endpoint,data=data,verify=self.verify_ssl)
+            r = self.auth_session.post("{}{}".format(self.base_url,endpoint),data=data,verify=self.verify_ssl)
             return r, r.content
         else:
             print("POST request to {} requires data: {}".format(endpoint,','.join(required_data)))
-            sys.exit(1)
+            return None,None
 
     @GET
     def subscribers_list(self, endpoint,method,data):
@@ -614,7 +584,7 @@ class StatusCastAPIDriver:
         currentPage		Number		page of results to return (defaults to 1)
         searchText		String		search by email address or full name
         """
-        r = self.auth_session.get(endpoint,data=data,verify=self.verify_ssl)
+        r = self.auth_session.get("{}{}".format(self.base_url,endpoint),data=data,verify=self.verify_ssl)
         return r, json.loads(r.content)
 
 
@@ -625,9 +595,9 @@ class StatusCastAPIDriver:
         if m(method) == "post":
             return self.updates_create(endpoint,method,data)
         if m(method) == "delete":
-            return self.updates_delete(endpoint,method,data)
+            return self.updates_delete("{}{}".format(self.base_url,endpoint),method,data)
         if m(method) == "get":
-            return self.updates_get(endpoint,method,data)
+            return self.updates_get("{}{}".format(self.base_url,endpoint),method,data)
 
     @POST
     def updates_create(self,endpoint,method,data):
@@ -641,11 +611,11 @@ class StatusCastAPIDriver:
         """
         required_data = ["postId","datePosted","messageText","postType"]
         if self.validate_data_keys(data,required_data):
-            r = self.auth_session.post(endpoint,data=data,verify=self.verify_ssl)
+            r = self.auth_session.post("{}{}".format(self.base_url,endpoint),data=data,verify=self.verify_ssl)
             return r, r.content
         else:
             print("POST request to {} requires data: {}".format(endpoint,','.join(required_data)))
-            sys.exit(1)
+            return None,None
 
     @DELETE
     def updates_delete(self,endpoint,method,data):
@@ -653,11 +623,11 @@ class StatusCastAPIDriver:
         Handler for /updates DELETE request; endpoint must be /updates?=<id to delete>
         """
         if "?id=" in endpoint:
-            r = self.auth_session.delete(endpoint,data=data,verify=self.verify_ssl)
+            r = self.auth_session.delete("{}{}".format(self.base_url,endpoint),data=data,verify=self.verify_ssl)
             return r, r.content
         else:
             print("DELETE request to {} requires data: ?id=<id to delete> in URL".format(endpoint))
-            sys.exit(1)
+            return None,None
 
     @GET
     def updates_get(self,endpoint,method,data):
@@ -665,40 +635,40 @@ class StatusCastAPIDriver:
         Handler for /updates GET request; endpoint must be /updates?=<id to get details for>
         """
         if "?id=" in endpoint:
-            r = self.auth_session.get(endpoint,data=data,verify=self.verify_ssl)
+            r = self.auth_session.get("{}{}".format(self.base_url,endpoint),data=data,verify=self.verify_ssl)
             return r, json.loads(r.content)
         else:
             print("GET request to {} requires ?id=<id to get details for> at end of URL".format(endpoint))
-            sys.exit(1)
+            return None,None
 
 
     def users_router(self,endpoint,method,data):
         """ Router for /users request ; can be Delete, Get, Put or Post"""
         if m(method) == "delete":
-            return self.users_delete(endpoint,method,data)
+            return self.users_delete("{}{}".format(self.base_url,endpoint),method,data)
         if m(method) == "get":
-            return self.users_get(endpoint,method,data)
+            return self.users_get("{}{}".format(self.base_url,endpoint),method,data)
         if m(method) == "post":
-            return self.users_create(endpoint,method,data)
+            return self.users_post(endpoint,method,data)
         if m(method) == "put":
-            return self.users_update(endpoint,method,data)
+            return self.users_put(endpoint,method,data)
         else:
             print("{} is an invalid method for endpoint {}; only accepts delete,get,put,post".format(method,endpoint))
-            sys.exit(1)
+            return None,None
 
     @DELETE
     def users_delete(self,endpoint,method,data):
         """ Handler for /users DELETE request , requires id as param """
         if "?id=" in endpoint:
-            r = self.auth_session.delete(endpoint,data=data,verify=self.verify_ssl)
+            r = self.auth_session.delete("{}{}".format(self.base_url,endpoint),data=data,verify=self.verify_ssl)
             return r, r.content
         else:
             print("DELETE request to {} requires data: ?id=<id to delete> in URL".format(endpoint))
-            sys.exit(1)
+            return None,None
     @GET
     def users_get(self,endpoint,method,data):
         """ Handler for /users GET request; optional /:<id of user> """
-        r = self.auth_session.get(endpoint,data=data,verify=self.verify_ssl)
+        r = self.auth_session.get("{}{}".format(self.base_url,endpoint),data=data,verify=self.verify_ssl)
         return r, json.loads(r.content)
 
     @PUT
@@ -714,12 +684,12 @@ class StatusCastAPIDriver:
 
         required_data = ["userName","fullName","adminAccess"]
         if self.validate_data_keys(data,required_data) and "?id=" in endpoint:
-            r = self.auth_session.put(endpoint,data=data,verify=self.verify_ssl)
+            r = self.auth_session.put("{}{}".format(self.base_url,endpoint),data=data,verify=self.verify_ssl)
             return r, r.content
         else:
             print("PUT request to {} requires ?id=<id of user to update> at end of URL and " + \
                         "data payload: {}".format(endpoint,','.join(required_data)))
-            sys.exit(1)
+            return None,None
     @POST
     def users_post(self,endpoint,method,data):
         """ Handler for /users POST request, data required:
@@ -731,10 +701,10 @@ class StatusCastAPIDriver:
         """
         required_data = ["userName","fullName","adminAccess"]
         if self.validate_data_keys(data,required_data):
-            r = self.auth_session.post(endpoint,data=data,verify=self.verify_ssl)
+            r = self.auth_session.post("{}{}".format(self.base_url,endpoint),data=data,verify=self.verify_ssl)
             return r, r.content
         else:
             print("POST request to {} requires data: {}".format(endpoint,','.join(required_data)))
-            sys.exit(1)
+            return None,None
 
 
